@@ -1,6 +1,7 @@
 from itertools import zip_longest
+from typing import List
 
-from .components import CrudComponent
+from .components import CrudComponent, JsonType
 from .plugins import KongEntityWithPlugins
 from .utils import as_list
 
@@ -13,29 +14,30 @@ class Routes(CrudComponent):
 
     Entity = KongEntityWithPlugins
 
-    async def delete(self, id_):
+    async def delete(self, id_: str) -> bool:
         route = self.wrap({"id": id_})
         await route.plugins.delete_all()
         return await super().delete(id_)
 
-    async def apply_json(self, data):
+    async def apply_json(self, data: JsonType, clear: bool = True) -> List:
         if not isinstance(data, list):
             data = [data]
         routes = await self.get_list()
         result = []
-        for d, route in zip_longest(data, routes):
-            if not d:
-                if route:
+        for entry, route in zip_longest(data, routes):
+            if not entry:
+                if route and clear:
                     await self.delete(route.id)
                 continue
-            plugins = d.pop("plugins", [])
-            as_list("hosts", d)
-            as_list("paths", d)
-            as_list("methods", d)
+            entry = entry.copy()
+            plugins = entry.pop("plugins", [])
+            as_list("hosts", entry)
+            as_list("paths", entry)
+            as_list("methods", entry)
             if not route:
-                route = await self.create(**d)
+                route = await self.create(**entry)
             else:
-                route = await self.update(route.id, **d)
+                route = await self.update(route.id, **entry)
             route.data["plugins"] = await route.plugins.apply_json(plugins)
             result.append(route.data)
         return result
